Path: csiph.com!x330-a1.tempe.blueboxinc.net!usenet.pasdenom.info!gegeweb.org!de-l.enfer-du-nord.net!feeder2.enfer-du-nord.net!feeder.erje.net!news-2.dfn.de!news.dfn.de!news.uni-stuttgart.de!news.nask.pl!news.nask.org.pl!newsfeed2.atman.pl!newsfeed.atman.pl!.POSTED!not-for-mail From: Edek Newsgroups: comp.programming.threads Subject: Re: False sharing Date: Tue, 31 May 2011 21:18:13 +0200 Organization: ATMAN - ATM S.A. Lines: 17 Message-ID: References: <18fa2208-ba1c-42c5-bf1f-280e6cbc41e6@bl1g2000vbb.googlegroups.com> NNTP-Posting-Host: 81.219.115.2 Mime-Version: 1.0 Content-Type: text/plain; charset=ISO-8859-1; format=flowed Content-Transfer-Encoding: 7bit X-Trace: node2.news.atman.pl 1306869492 26127 81.219.115.2 (31 May 2011 19:18:12 GMT) X-Complaints-To: usenet@atman.pl NNTP-Posting-Date: Tue, 31 May 2011 19:18:12 +0000 (UTC) User-Agent: Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.17) Gecko/20110428 Linux/3.1.0-15 Thunderbird/3.1.0 In-Reply-To: Xref: x330-a1.tempe.blueboxinc.net comp.programming.threads:215 I made one more test, of (work += i). This time with a single thread (it can be argued there is no false-sharing with a single thread ;) ). Two threads: real 0m3.449s user 0m3.274s sys 0m0.015s One thread: real 0m3.465s user 0m6.318s sys 0m0.037s Of course, the loop count is 10x smaller than yours. Edek